@@ -160,7 +160,9 @@ gcm_calibrate_argyll_get_display (const gchar *output_name,
 {
 	gboolean ret = FALSE;
 	gchar *command = NULL;
-	gchar *data = NULL;
+	const gchar *data;
+	gchar *data_stderr = NULL;
+	gchar *data_stdout = NULL;
 	gchar *name;
 	gchar **split = NULL;
 	gint exit_status;
@@ -174,13 +176,26 @@ gcm_calibrate_argyll_get_display (const gchar *output_name,
 
 	/* execute it and capture stderr */
 	ret = g_spawn_command_line_sync (command,
-					 NULL,
-					 &data,
+					 &data_stdout,
+					 &data_stderr,
 					 &exit_status,
 					 error);
 	if (!ret)
 		goto out;
 
+	/* recent versions of dispcal switched to stderr output */
+	if (data_stdout != NULL && data_stdout[0] != '\0') {
+		data = data_stdout;
+	} else if (data_stderr != NULL && data_stderr[0] != '\0') {
+		data = data_stderr;
+	} else {
+		g_set_error_literal (error,
+				     GCM_CALIBRATE_ERROR,
+				     GCM_CALIBRATE_ERROR_INTERNAL,
+				     "no sensible output from dispcal");
+		goto out;
+	}
+
 	/* split it into lines */
 	split = g_strsplit (data, "\n", -1);
 	for (i=0; split[i] != NULL; i++) {
@@ -210,7 +225,8 @@ gcm_calibrate_argyll_get_display (const gchar *output_name,
 	}
 out:
 	g_free (command);
-	g_free (data);
+	g_free (data_stdout);
+	g_free (data_stderr);
 	g_strfreev (split);
 	return display;
 }
@@ -678,6 +694,7 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 	g_ptr_array_add (array, g_strdup_printf ("-C%s", copyright));
 	g_ptr_array_add (array, g_strdup (gcm_calibrate_argyll_get_quality_arg (calibrate_argyll)));
 	g_ptr_array_add (array, g_strdup ("-aG"));
+	g_ptr_array_add (array, g_strdup ("-Zp"));
 	g_ptr_array_add (array, g_strdup (basename));
 	argv = gcm_utils_ptr_array_to_strv (array);
 	gcm_calibrate_argyll_debug_argv (command, argv);
